def process_rexel_data(data):
    """
    Verwerk Rexel data en geef een resultaat terug.
    """
    product_number = data['product_number']
    part_number = data['part_number']

    # Verwerking (voorbeeld)
    return {
        'product_number': product_number,
        'part_number': part_number,
        'status': 'success',
        'message': f'Processed part {part_number} for product {product_number}.'
    }



from rest_framework import serializers


class RexelRequestSerializer(serializers.Serializer):
    """Serializer voor validatie van Rexel data."""
    product_number = serializers.CharField(
        max_length=255,
        required=True,
        source='product_number'
    )
    part_number = serializers.CharField(
        max_length=255,
        required=True,
        source='part_number'
    )
